/**
 * @typedef {'svelte.dev' | 'kit.svelte.dev' | 'learn.svelte.dev'} BannerScope
 *
 * @typedef {{
 * id: string;
 * start: number;
 * end: number;
 * arrow: boolean;
 * href: string;
 * content: string;
 * scope?: BannerScope[];
 * }[]} BannerData
 *
 * @typedef {(Omit<BannerData[0], 'start' | 'end'> & { start: Date, end?: Date })[]} BannerDataInput
 */
/**
 * Only to be used on non svelte.dev sites. Shouldn't be used inside svelte.dev codebase itself
 * @param {BannerScope} scope
 * @param {import('@sveltejs/kit').RequestEvent['fetch']} fetch
 * @returns {Promise<BannerData>}
 */
export function fetchBanner(scope: BannerScope | undefined, fetch: import('@sveltejs/kit').RequestEvent['fetch']): Promise<BannerData>;
/**
 * @param {BannerDataInput} data
 * @returns {BannerData}
 */
export function defineBanner(data: BannerDataInput): BannerData;
/** @typedef {typeof __propDef.props}  BannersProps */
/** @typedef {typeof __propDef.events}  BannersEvents */
/** @typedef {typeof __propDef.slots}  BannersSlots */
export default class Banners extends SvelteComponent<{
    data: BannerData;
}, {
    [evt: string]: CustomEvent<any>;
}, {}> {
}
export type BannerScope = 'svelte.dev' | 'kit.svelte.dev' | 'learn.svelte.dev';
export type BannerData = {
    id: string;
    start: number;
    end: number;
    arrow: boolean;
    href: string;
    content: string;
    scope?: BannerScope[];
}[];
export type BannerDataInput = (Omit<{
    id: string;
    start: number;
    end: number;
    arrow: boolean;
    href: string;
    content: string;
    scope?: BannerScope[] | undefined;
}[][0], 'start' | 'end'> & {
    start: Date;
    end?: Date;
})[];
export type BannersProps = typeof __propDef.props;
export type BannersEvents = typeof __propDef.events;
export type BannersSlots = typeof __propDef.slots;
import { SvelteComponent } from "svelte";
declare const __propDef: {
    props: {
        data: BannerData;
    };
    events: {
        [evt: string]: CustomEvent<any>;
    };
    slots: {};
};
export {};
